#ifndef CMDHISTORY_H__
#define CMDHISTORY_H__

#include <gtk/gtk.h>
#include <glade/glade.h>

extern GladeXML *xmlmain;
#define CMD_HISTORY_DEPTH_MIN	0
#define CMD_HISTORY_DEPTH_MAX	99

#define CMD_HISTORY_DEPTH	gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(xmlmain, "set_command_history_depth")))

struct cmd_history_t {
    struct cmd_history_t *prev;
    struct cmd_history_t *next;
    gchar text[257];
};

typedef struct cmd_history_t SilkyCmdHistoryItem;

gchar *cmd_history_prev(void);
gchar *cmd_history_next(void);

void cmd_history_push(char *text);

#endif
